import _defineProperty from "@babel/runtime/helpers/esm/defineProperty";
import React from "react";
import { BOTTOM_LEFT, POSITIONS, isBottom, isCenter, isLeft, isRight, isTop } from "./positions";
import { FadeIn } from "./fade-in";
import { Popup } from "@orbit-ui/react-popup";
import { PureComponent } from "react";
import { arrayOf, bool, func, node, number, oneOf, string } from "prop-types";
import { isNil } from "lodash";
import { useHandlerProxy } from "@orbit-ui/react-components-shared";
export class DatePickerAnchor extends PureComponent {
  constructor() {
    super(...arguments);

    _defineProperty(this, "handleOutsideClick", useHandlerProxy(this, "onOutsideClick"));

    _defineProperty(this, "handleEscapeKeyDown", useHandlerProxy(this, "onEscapeKeyDown"));
  }

  getHorizontalPosition() {
    const {
      position,
      offsets
    } = this.props;

    if (isLeft(position)) {
      return {
        left: "0px",
        offsetX: offsets[0]
      };
    } else if (isRight(position)) {
      return {
        right: "0px",
        offsetX: offsets[0]
      };
    } else if (isCenter(position)) {
      return {
        left: "50%",
        offsetX: "calc(-50% + ".concat(offsets[0], ")")
      };
    }

    return {};
  }

  getVerticalPosition() {
    const {
      position,
      offsets,
      inputHeight
    } = this.props;

    if (isBottom(position)) {
      return {
        top: "".concat(inputHeight, "px"),
        offsetY: offsets[1]
      };
    } else if (isTop(position)) {
      return {
        bottom: "".concat(inputHeight, "px"),
        offsetY: "-".concat(offsets[1].startsWith("-") ? offsets[1].substring(1) : offsets[1])
      };
    }

    return {};
  }

  getCssClasses() {
    const {
      className
    } = this.props;
    const defaultClasses = "relative";
    return isNil(className) ? defaultClasses : "".concat(defaultClasses, " ").concat(className);
  }

  render() {
    const {
      input,
      inputHeight,
      calendar,
      open,
      disabled
    } = this.props;
    return React.createElement("div", {
      className: this.getCssClasses()
    }, input, !isNil(inputHeight) && !disabled ? React.createElement(FadeIn, {
      active: open
    }, React.createElement(Popup, Object.assign({
      visible: open,
      onOutsideClick: this.handleOutsideClick,
      onEscapeKeyDown: this.handleEscapeKeyDown
    }, this.getHorizontalPosition(), this.getVerticalPosition()), calendar)) : null);
  }

}

_defineProperty(DatePickerAnchor, "defaultProps", {
  position: BOTTOM_LEFT,
  offsets: ["0px", "10px"]
});