import _defineProperty from "@babel/runtime/helpers/esm/defineProperty";
import React from "react";
import { AutoControlledPureComponent, getAutoControlledStateFromProps } from "@orbit-ui/react-components-shared";
import { DatePickerAnchor } from "../date-picker-anchor";
import { DateRangePickerButtons } from "./date-range-picker-buttons";
import { DateRangePickerCalendar } from "./date-range-picker-calendar";
import { DateRangePickerInput } from "./date-range-picker-input";
import { DateRangePickerPresets } from "./date-range-picker-presets";
import { POSITIONS } from "../positions";
import { PRESET_SHAPE } from "./presets";
import { arrayOf, bool, func, node, number, oneOf, oneOfType, shape, string } from "prop-types";
import { cloneElement } from "react";
import { isNil } from "lodash";
import { momentObj as momentType } from "react-moment-proptypes";
export class DateRangePicker extends AutoControlledPureComponent {
  constructor() {
    super(...arguments);

    _defineProperty(this, "state", {
      startDate: null,
      endDate: null,
      selectedStartDate: null,
      selectedEndDate: null,
      selectedPresetName: null,
      open: false,
      inputHeight: null
    });

    _defineProperty(this, "handleInputBoundingClientRectChange", (_ref) => {
      let {
        height
      } = _ref;
      this.setState({
        inputHeight: height
      });
    });

    _defineProperty(this, "handleInputOpen", event => {
      const {
        open
      } = this.state;

      if (!open) {
        this.toggleCalendarVisibility(event);
      }
    });

    _defineProperty(this, "handleInputClose", event => {
      const {
        open
      } = this.state;

      if (open) {
        this.toggleCalendarVisibility(event);
      }
    });

    _defineProperty(this, "handleInputClear", event => {
      const {
        onDatesChange
      } = this.props;
      this.trySetAutoControlledStateValue({
        startDate: null
      });
      this.trySetAutoControlledStateValue({
        endDate: null
      });
      this.setState({
        selectedStartDate: null,
        selectedEndDate: null,
        selectedPresetName: null
      });
      onDatesChange(event, null, null, null, this.props);
    });

    _defineProperty(this, "handlePopupClose", event => {
      const {
        startDate,
        endDate
      } = this.state;
      this.setState({
        selectedStartDate: startDate,
        selectedEndDate: endDate,
        selectedPresetName: null
      });
      this.toggleCalendarVisibility(event);
    });

    _defineProperty(this, "handleCalendarDatesChange", (startDate, endDate, presetName) => {
      this.setState({
        selectedStartDate: startDate,
        selectedEndDate: endDate,
        selectedPresetName: presetName
      });
    });

    _defineProperty(this, "handleCalendarApply", event => {
      const {
        onDatesChange
      } = this.props;
      const {
        selectedStartDate,
        selectedEndDate,
        selectedPresetName
      } = this.state;
      this.toggleCalendarVisibility(event);
      this.trySetAutoControlledStateValue({
        startDate: selectedStartDate
      });
      this.trySetAutoControlledStateValue({
        endDate: selectedEndDate
      });
      onDatesChange(event, selectedStartDate, selectedEndDate, selectedPresetName, this.props);
    });
  }

  static getDerivedStateFromProps(props, state) {
    return getAutoControlledStateFromProps(props, state, DateRangePicker.autoControlledProps, (_ref2) => {
      let {
        startDate,
        endDate
      } = _ref2;
      return {
        selectedStartDate: startDate,
        selectedEndDate: endDate
      };
    });
  }

  toggleCalendarVisibility(event) {
    const {
      onVisibilityChange
    } = this.props;
    const {
      open
    } = this.state;
    this.trySetAutoControlledStateValue({
      open: !open
    });

    if (!isNil(onVisibilityChange)) {
      onVisibilityChange(event, !open, this.props);
    }
  }

  renderInput() {
    const {
      input,
      allowClear,
      placeholder,
      rangeFormat,
      dateFormat,
      disabled
    } = this.props;
    const {
      selectedStartDate,
      selectedEndDate,
      open
    } = this.state;
    return cloneElement(input, {
      startDate: selectedStartDate,
      endDate: selectedEndDate,
      onOpen: this.handleInputOpen,
      onClose: this.handleInputClose,
      onClear: this.handleInputClear,
      onBoundingClientRectChange: this.handleInputBoundingClientRectChange,
      allowClear,
      placeholder,
      rangeFormat,
      dateFormat,
      disabled: disabled,
      open: open
    });
  }

  renderCalendar() {
    const {
      allowSingleDateSelection,
      allowClear,
      minDate,
      maxDate,
      initialVisibleMonth,
      numberOfMonths,
      calendar,
      presetsComponent,
      presets,
      buttons
    } = this.props;
    const {
      selectedStartDate,
      selectedEndDate
    } = this.state;
    return cloneElement(calendar, {
      startDate: selectedStartDate,
      endDate: selectedEndDate,
      onDatesChange: this.handleCalendarDatesChange,
      onApply: this.handleCalendarApply,
      allowSingleDateSelection,
      allowClear,
      minDate,
      maxDate,
      initialVisibleMonth,
      numberOfMonths,
      presetsComponent,
      presets,
      buttons
    });
  }

  render() {
    const {
      position,
      offsets,
      disabled,
      className
    } = this.props;
    const {
      open,
      inputHeight
    } = this.state;
    return React.createElement(DatePickerAnchor, {
      input: this.renderInput(),
      inputHeight: inputHeight,
      calendar: this.renderCalendar(),
      open: open,
      position: position,
      offsets: offsets,
      onOutsideClick: this.handlePopupClose,
      onEscapeKeyDown: this.handlePopupClose,
      disabled: disabled,
      className: className
    });
  }

}

_defineProperty(DateRangePicker, "propTypes", {
  startDate: momentType,
  endDate: momentType,
  defaultStartDate: momentType,
  defaultEndDate: momentType,
  onDatesChange: func.isRequired,
  onVisibilityChange: func,
  allowSingleDateSelection: bool,
  allowClear: bool,
  minDate: momentType,
  maxDate: momentType,
  initialVisibleMonth: oneOfType([momentType, func]),
  numberOfMonths: number,
  input: node,
  placeholder: string,
  rangeFormat: string,
  dateFormat: string,
  position: oneOf(POSITIONS),
  offsets: arrayOf(string),
  calendar: node,
  presetsComponent: node,
  presets: arrayOf(shape(PRESET_SHAPE)),
  buttons: node,
  defaultOpen: bool,
  open: bool,
  disabled: bool,
  className: string
});

_defineProperty(DateRangePicker, "defaultProps", {
  allowSingleDateSelection: false,
  allowClear: true,
  numberOfMonths: 2,
  input: React.createElement(DateRangePickerInput, null),
  dateFormat: "MMM Do YYYY",
  calendar: React.createElement(DateRangePickerCalendar, null),
  presetsComponent: React.createElement(DateRangePickerPresets, null),
  presets: [],
  buttons: React.createElement(DateRangePickerButtons, null),
  disabled: false
});

_defineProperty(DateRangePicker, "autoControlledProps", ["startDate", "endDate", "open"]);

_defineProperty(DateRangePicker, "Input", DateRangePickerInput);

_defineProperty(DateRangePicker, "Calendar", DateRangePickerCalendar);

_defineProperty(DateRangePicker, "Presets", DateRangePickerPresets);

_defineProperty(DateRangePicker, "Buttons", DateRangePickerButtons);