import _defineProperty from "@babel/runtime/helpers/esm/defineProperty";
import React from "react";
import { DatePickerCalendar } from "../date-picker-calendar";
import { DayPickerSingleDateController } from "react-dates";
import { POSITIONS } from "../positions";
import { PureComponent, cloneElement } from "react";
import { bool, func, node, number, oneOf, oneOfType, string } from "prop-types";
import { momentObj as momentType } from "react-moment-proptypes";
import moment from "moment";
export class SingleDatePickerCalendar extends PureComponent {
  constructor() {
    super(...arguments);

    _defineProperty(this, "state", {
      focused: true
    });

    _defineProperty(this, "handleDateChange", date => {
      const {
        onDateChange
      } = this.props;
      onDateChange(date, this.props);
    });

    _defineProperty(this, "handleFocusChange", (_ref) => {
      let {
        focused
      } = _ref;
      this.setState({
        focused
      });
    });

    _defineProperty(this, "handleClear", () => {
      const {
        onDateChange
      } = this.props;
      onDateChange(null, this.props);
    });

    _defineProperty(this, "handleApply", event => {
      const {
        onApply
      } = this.props;
      onApply(event, this.props);
    });
  }

  getInitialDate() {
    const {
      date
    } = this.props;
    return date || moment();
  }

  renderButtons() {
    const {
      date,
      allowClear,
      buttons
    } = this.props;
    return cloneElement(buttons, {
      date,
      onClear: this.handleClear,
      onApply: this.handleApply,
      allowClear
    });
  }

  renderCalendar() {
    const {
      date
    } = this.props;
    const {
      focused
    } = this.state;
    return React.createElement(DayPickerSingleDateController, {
      date: date,
      focused: focused,
      onDateChange: this.handleDateChange,
      onFocusChange: this.handleFocusChange
    });
  }

  render() {
    const {
      minDate,
      maxDate,
      initialVisibleMonth,
      numberOfMonths,
      position,
      navPrevIcon,
      navNextIcon,
      className
    } = this.props;
    return React.createElement(DatePickerCalendar, {
      calendar: this.renderCalendar(),
      buttons: this.renderButtons(),
      minDate: minDate,
      maxDate: maxDate,
      initialDate: this.getInitialDate(),
      initialVisibleMonth: initialVisibleMonth,
      numberOfMonths: numberOfMonths,
      position: position,
      navPrevIcon: navPrevIcon,
      navNextIcon: navNextIcon,
      className: className,
      temporarySingleDatePickerFlag: true
    });
  }

}