import _defineProperty from "@babel/runtime/helpers/esm/defineProperty";
import React from "react";
import { AutoControlledPureComponent, getAutoControlledStateFromProps } from "@orbit-ui/react-components-shared";
import { DatePickerAnchor } from "../date-picker-anchor";
import { POSITIONS } from "../positions";
import { SingleDatePickerButtons } from "./single-date-picker-buttons";
import { SingleDatePickerCalendar } from "./single-date-picker-calendar";
import { SingleDatePickerInput } from "./single-date-picker-input";
import { arrayOf, bool, func, node, number, oneOf, oneOfType, string } from "prop-types";
import { cloneElement } from "react";
import { isNil } from "lodash";
import { momentObj as momentType } from "react-moment-proptypes";
export const SINGLE_DATE_PICKER_PROP_TYPES = {
  date: momentType,
  defaultDate: momentType,
  onDateChange: func.isRequired,
  onVisibilityChange: func,
  allowClear: bool,
  minDate: momentType,
  maxDate: momentType,
  initialVisibleMonth: oneOfType([momentType, func]),
  numberOfMonths: number,
  input: node,
  placeholder: string,
  dateFormat: string,
  position: oneOf(POSITIONS),
  offsets: arrayOf(string),
  calendar: node,
  buttons: node,
  defaultOpen: bool,
  open: bool,
  disabled: bool,
  className: string
};
export class SingleDatePicker extends AutoControlledPureComponent {
  constructor() {
    super(...arguments);

    _defineProperty(this, "state", {
      date: null,
      selectedDate: null,
      open: false,
      inputHeight: null
    });

    _defineProperty(this, "handleInputBoundingClientRectChange", (_ref) => {
      let {
        height
      } = _ref;
      this.setState({
        inputHeight: height
      });
    });

    _defineProperty(this, "handleInputOpen", event => {
      const {
        open
      } = this.state;

      if (!open) {
        this.toggleCalendarVisibility(event);
      }
    });

    _defineProperty(this, "handleInputClose", event => {
      const {
        open
      } = this.state;

      if (open) {
        this.toggleCalendarVisibility(event);
      }
    });

    _defineProperty(this, "handleInputClear", event => {
      const {
        onDateChange
      } = this.props;
      this.trySetAutoControlledStateValue({
        date: null
      });
      this.setState({
        selectedDate: null
      });
      onDateChange(event, null, this.props);
    });

    _defineProperty(this, "handlePopupClose", event => {
      const {
        date
      } = this.state;
      this.setState({
        selectedDate: date
      });
      this.toggleCalendarVisibility(event);
    });

    _defineProperty(this, "handleCalendarDateChange", date => {
      this.setState({
        selectedDate: date
      });
    });

    _defineProperty(this, "handleCalendarApply", event => {
      const {
        onDateChange
      } = this.props;
      const {
        selectedDate
      } = this.state;
      this.toggleCalendarVisibility(event);
      this.trySetAutoControlledStateValue({
        date: selectedDate
      });
      onDateChange(event, selectedDate, this.props);
    });
  }

  static getDerivedStateFromProps(props, state) {
    return getAutoControlledStateFromProps(props, state, SingleDatePicker.autoControlledProps, (_ref2) => {
      let {
        date
      } = _ref2;
      return {
        selectedDate: date
      };
    });
  }

  toggleCalendarVisibility(event) {
    const {
      onVisibilityChange
    } = this.props;
    const {
      open
    } = this.state;
    this.trySetAutoControlledStateValue({
      open: !open
    });

    if (!isNil(onVisibilityChange)) {
      onVisibilityChange(event, !open, this.props);
    }
  }

  renderInput() {
    const {
      input,
      allowClear,
      numberOfMonths,
      placeholder,
      dateFormat,
      disabled
    } = this.props;
    const {
      selectedDate,
      open
    } = this.state;
    return cloneElement(input, {
      date: selectedDate,
      onOpen: this.handleInputOpen,
      onClose: this.handleInputClose,
      onClear: this.handleInputClear,
      onBoundingClientRectChange: this.handleInputBoundingClientRectChange,
      allowClear,
      numberOfMonths,
      placeholder,
      dateFormat,
      disabled: disabled,
      open: open
    });
  }

  renderCalendar() {
    const {
      allowClear,
      minDate,
      maxDate,
      initialVisibleMonth,
      numberOfMonths,
      calendar,
      buttons
    } = this.props;
    const {
      selectedDate
    } = this.state;
    return cloneElement(calendar, {
      date: selectedDate,
      onDateChange: this.handleCalendarDateChange,
      onApply: this.handleCalendarApply,
      allowClear,
      minDate,
      maxDate,
      initialVisibleMonth,
      numberOfMonths,
      buttons
    });
  }

  render() {
    const {
      position,
      offsets,
      disabled,
      className
    } = this.props;
    const {
      open,
      inputHeight
    } = this.state;
    return React.createElement(DatePickerAnchor, {
      input: this.renderInput(),
      inputHeight: inputHeight,
      calendar: this.renderCalendar(),
      open: open,
      position: position,
      offsets: offsets,
      onOutsideClick: this.handlePopupClose,
      onEscapeKeyDown: this.handlePopupClose,
      disabled: disabled,
      className: className
    });
  }

}

_defineProperty(SingleDatePicker, "propTypes", SINGLE_DATE_PICKER_PROP_TYPES);

_defineProperty(SingleDatePicker, "defaultProps", {
  allowClear: true,
  dateFormat: "MMM Do YYYY",
  numberOfMonths: 1,
  input: React.createElement(SingleDatePickerInput, null),
  calendar: React.createElement(SingleDatePickerCalendar, null),
  buttons: React.createElement(SingleDatePickerButtons, null),
  disabled: false
});

_defineProperty(SingleDatePicker, "autoControlledProps", ["date", "open"]);

_defineProperty(SingleDatePicker, "Input", SingleDatePickerInput);

_defineProperty(SingleDatePicker, "Calendar", SingleDatePickerCalendar);

_defineProperty(SingleDatePicker, "Buttons", SingleDatePickerButtons);