import _defineProperty from "@babel/runtime/helpers/esm/defineProperty";
import React from "react";
import { Button } from "semantic-ui-react";
import { KEYS, useHandlerProxy } from "@orbit-ui/react-components-shared";
import { PureComponent, createRef } from "react";
import { bool, func, node, string } from "prop-types";
import { isNil } from "lodash";
export class MultiSelectDropdownTrigger extends PureComponent {
  constructor() {
    super(...arguments);

    _defineProperty(this, "_buttonRef", createRef());

    _defineProperty(this, "handleFocus", useHandlerProxy(this, "onFocus"));

    _defineProperty(this, "handleBlur", useHandlerProxy(this, "onBlur"));

    _defineProperty(this, "handleClick", event => {
      const {
        onClick,
        onOpen,
        disabled
      } = this.props;

      if (!isNil(onClick)) {
        onClick(event, this.props);
      }

      if (!disabled) {
        onOpen(event, this.props);
      }
    });

    _defineProperty(this, "handleKeyDown", event => {
      const {
        onKeyDown,
        onOpen,
        disabled
      } = this.props;

      if (!isNil(onKeyDown)) {
        onKeyDown(event, this.props);
      }

      const key = event.keyCode;

      if (key === KEYS.space) {
        if (!disabled) {
          onOpen(event, this.props);
        }
      }
    });
  }

  getClasses() {
    const {
      className
    } = this.props;
    const defaultClasses = "tall";
    return isNil(className) ? defaultClasses : "".concat(defaultClasses, " ").concat(className);
  }

  renderIcon() {
    const {
      icon,
      disabledIcon,
      disabled
    } = this.props;
    return disabled ? disabledIcon : icon;
  }

  render() {
    const {
      text
    } = this.props;
    return React.createElement("div", {
      className: "mr2 mb2"
    }, React.createElement(Button, {
      onClick: this.handleClick,
      onKeyDown: this.handleKeyDown,
      onFocus: this.handleFocus,
      onBlur: this.handleBlur,
      secondary: true,
      className: this.getClasses(),
      ref: this._buttonRef
    }, text, " ", this.renderIcon()));
  } // This function is part of the component external API.


  focus() {
    this._buttonRef.current.focus();
  }

}